# remirepo/fedora spec file for php-brick-varexporter
#
# SPDX-FileCopyrightText:  Copyright 2020-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#
# Github
%global gh_commit    af98bfc2b702a312abbcaff37656dbe419cec5bc
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     brick
%global gh_project   varexporter
# Packagist
%global pk_vendor    %{gh_owner}
%global pk_name      %{gh_project}
# Namespace
%global ns_vendor    Brick
%global ns_project   VarExporter

Name:           php-%{pk_vendor}-%{pk_name}
Version:        0.6.0
Release:        1%{?dist}
Summary:        A powerful alternative to var_export

License:        MIT
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        %{name}-%{version}-%{gh_short}.tgz
# Create git snapshot as tests are excluded from official tarball
Source1:        makesrc.sh

BuildArch:      noarch

BuildRequires:  php(language) >= 8.1
BuildRequires: (php-composer(nikic/php-parser) >= 5.0   with php-composer(nikic/php-parser) < 6)
BuildRequires:  php-reflection
BuildRequires:  php-date
BuildRequires:  php-pcre
BuildRequires:  php-spl
# From composer.json, "require-dev": {
#    "phpunit/phpunit": "^10.5",
#    "php-coveralls/php-coveralls": "^2.2",
#    "vimeo/psalm": "6.8.4"
BuildRequires:  phpunit10 >= 10.5
%global phpunit %{_bindir}/phpunit10
# Autoloader
BuildRequires:  php-fedora-autoloader-devel

# From composer.json, "require": {
#    "php": "^8.1",
#    "nikic/php-parser": "^5.0"
Requires:       php(language) >= 8.1
Requires:      (php-composer(nikic/php-parser) >= 5.0   with php-composer(nikic/php-parser) < 6)
# From phpcompatifo report for 0.3.2
Requires:       php-reflection
Requires:       php-pcre
Requires:       php-spl
# Autoloader
Requires:       php-composer(fedora/autoloader)

Provides:       php-composer(%{pk_vendor}/%{pk_name}) = %{version}


%description
This library aims to provide a prettier, safer, and powerful alternative
to var_export(). The output is valid and standalone PHP code, that does
not depend on the brick/varexporter library.

Autoloader: %{_datadir}/php/%{ns_vendor}/%{ns_project}/autoload.php


%prep
%setup -q -n %{gh_project}-%{gh_commit}


%build
: Create classmap autoloader
phpab \
  --template fedora \
  --output src/autoload.php \
  src

cat << 'EOF' | tee -a src/autoload.php

\Fedora\Autoloader\Dependencies::required([
    '/usr/share/php/PhpParser5/autoload.php',
]);

EOF

%install
# Restore PSR-0 tree
mkdir -p   %{buildroot}%{_datadir}/php/%{ns_vendor}
cp -pr src %{buildroot}%{_datadir}/php/%{ns_vendor}/%{ns_project}


%check
: Generate a simple autoloader
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
// Installed library
require '%{buildroot}%{_datadir}/php/%{ns_vendor}/%{ns_project}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('Brick\\VarExporter\\Tests\\', dirname(__DIR__) . '/tests');
EOF

: Run upstream test suite
ret=0
for cmdarg in "php %{phpunit}" php81 php82 php83 php84; do
  if which $cmdarg; then
    set $cmdarg
    $1 ${2:-%{_bindir}/phpunit10} \
      --no-coverage || ret=1
  fi
done
exit $ret


%files
%license LICENSE
%doc *.md
%doc composer.json
%{_datadir}/php/%{ns_vendor}


%changelog
* Tue Feb 25 2025 Remi Collet <remi@remirepo.net> - 0.6.0-1
- update to 0.6.0
- re-license spec file to CECILL-2.1
- raise dependency on PHP 8.1

* Mon May 13 2024 Remi Collet <remi@remirepo.net> - 0.5.0-1
- update to 0.5.0
- raise dependency on nikic/php-parser 5.0

* Mon Sep  4 2023 Remi Collet <remi@remirepo.net> - 0.4.0-1
- update to 0.4.0
- raise dependency on PHP 7.4

* Wed Jan 25 2023 Remi Collet <remi@remirepo.net> - 0.3.8-1
- update to 0.3.8

* Thu Jun 30 2022 Remi Collet <remi@remirepo.net> - 0.3.7-1
- update to 0.3.7

* Thu Jun 16 2022 Remi Collet <remi@remirepo.net> - 0.3.6-1
- update to 0.3.6

* Wed Nov 24 2021 Remi Collet <remi@remirepo.net> - 0.3.5-3
- add upstream patch to fix test suite with PHP 8.1

* Wed Feb 10 2021 Remi Collet <remi@remirepo.net> - 0.3.5-1
- update to 0.3.5

* Mon Feb  8 2021 Remi Collet <remi@remirepo.net> - 0.3.4-1
- update to 0.3.4

* Mon Jan  4 2021 Remi Collet <remi@remirepo.net> - 0.3.3-1
- update to 0.3.3
- switch to phpunit9

* Tue Aug 25 2020 Remi Collet <remi@remirepo.net> - 0.3.2-1
- initial package
